@@ -1,6 +1,6 @@
 <?php
     /**
-     * Copyright (c) 2010-2015 Arne Blankerts <arne@blankerts.de>
+     * Copyright (c) 2010-2018 Arne Blankerts <arne@blankerts.de>
      * All rights reserved.
      *
      * Redistribution and use in source and binary forms, with or without modification,
@@ -44,9 +44,11 @@ namespace TheSeer\phpDox\Collector\Backend {
 
         /**
          * @param SourceFile $sourceFile
+         * @param bool $publicOnly
+         *
          * @return ParseResult
          */
-        public function parse(SourceFile $sourceFile);
+        public function parse(SourceFile $sourceFile, $publicOnly);
 
     }
 }
