@@ -1,6 +1,6 @@
 <?php
     /**
-     * Copyright (c) 2010-2015 Arne Blankerts <arne@blankerts.de>
+     * Copyright (c) 2010-2018 Arne Blankerts <arne@blankerts.de>
      * All rights reserved.
      *
      * Redistribution and use in source and binary forms, with or without modification,
@@ -36,6 +36,19 @@
      */
 namespace TheSeer\phpDox\Collector\Backend {
 
+    use PhpParser\Node\Expr;
+    use PhpParser\Node\Expr\Array_;
+    use PhpParser\Node\Expr\BinaryOp;
+    use PhpParser\Node\Expr\ClassConstFetch;
+    use PhpParser\Node\Expr\ConstFetch;
+    use PhpParser\Node\Expr\UnaryMinus;
+    use PhpParser\Node\Expr\UnaryPlus;
+    use PhpParser\Node\Name\FullyQualified;
+    use PhpParser\Node\NullableType;
+    use PhpParser\Node\Scalar\DNumber;
+    use PhpParser\Node\Scalar\LNumber;
+    use PhpParser\Node\Scalar\MagicConst;
+    use PhpParser\Node\Scalar\String_;
     use TheSeer\phpDox\Collector\AbstractUnitObject;
     use TheSeer\phpDox\Collector\AbstractVariableObject;
     use TheSeer\phpDox\Collector\InlineComment;
@@ -91,13 +104,15 @@ namespace TheSeer\phpDox\Collector\Backend {
 
         /**
          * @param \PhpParser\Node $node
+         *
+         * @return int|null|\PhpParser\Node|void
          */
         public function enterNode(\PhpParser\Node $node) {
             if ($node instanceof NodeType\Namespace_ && $node->name != NULL) {
-                $this->namespace = join('\\', $node->name->parts);
+                $this->namespace = implode('\\', $node->name->parts);
                 $this->aliasMap['::context'] = $this->namespace;
             } else if ($node instanceof NodeType\UseUse) {
-                $this->aliasMap[$node->alias] = join('\\', $node->name->parts);
+                $this->aliasMap[$node->alias] = implode('\\', $node->name->parts);
             } else if ($node instanceof NodeType\Class_) {
                 $this->aliasMap['::unit'] = (string)$node->namespacedName;
                 $this->unit = $this->result->addClass((string)$node->namespacedName);
@@ -128,6 +143,8 @@ namespace TheSeer\phpDox\Collector\Backend {
 
         /**
          * @param \PhpParser\Node $node
+         *
+         * @return false|int|null|\PhpParser\Node|\PhpParser\Node[]|void
          */
         public function leaveNode(\PhpParser\Node $node) {
             if ($node instanceof NodeType\Class_
@@ -158,20 +175,20 @@ namespace TheSeer\phpDox\Collector\Backend {
                 $this->unit->setDocBlock($block);
             }
 
-            if ($node->getType() != 'Stmt_Trait' && $node->extends != NULL) {
+            if ($node->getType() != 'Stmt_Trait' && $node->extends !== NULL) {
                 if (is_array($node->extends)) {
-                    foreach($node->extends as $extends) {
-                        $this->unit->addExtends(join('\\', $extends->parts));
+                    $extendsArray = $node->extends;
+                    foreach ($extendsArray as $extends) {
+                        $this->unit->addExtends(implode('\\', $extends->parts));
                     }
                 } else {
-                    $this->unit->addExtends(join('\\', $node->extends->parts));
+                    $this->unit->addExtends(implode('\\', $node->extends->parts));
                 }
-
             }
 
-            if ($node->getType() == 'Stmt_Class') {
+            if ($node->getType() === 'Stmt_Class') {
                 foreach($node->implements as $implements) {
-                    $this->unit->addImplements(join('\\', $implements->parts));
+                    $this->unit->addImplements(implode('\\', $implements->parts));
                 }
             }
         }
@@ -185,27 +202,40 @@ namespace TheSeer\phpDox\Collector\Backend {
 
             foreach($node->adaptations as $adaptation) {
                 if ($adaptation instanceof NodeType\TraitUseAdaptation\Alias) {
-                    $traitUse = $this->getTraitUse((string)$adaptation->trait);
+                    if ($adaptation->trait instanceof FullyQualified) {
+                        $traitUse = $this->getTraitUse((string)$adaptation->trait);
+                    } else if (count($node->traits) === 1) {
+                        $traitUse = $this->getTraitUse( (string)$node->traits[0]);
+                    } else {
+                        $traitUse = $this->unit->getAmbiguousTraitUse();
+                    }
+
                     $traitUse->addAlias(
                         $adaptation->method,
                         $adaptation->newName,
                         $adaptation->newModifier ? $this->modifier[$adaptation->newModifier] : NULL
                     );
-                } elseif ($adaptation instanceof NodeType\TraitUseAdaptation\Precedence) {
+
+                    continue;
+                }
+
+                if ($adaptation instanceof NodeType\TraitUseAdaptation\Precedence) {
                     $traitUse = $this->getTraitUse((string)$adaptation->insteadof[0]);
                     $traitUse->addExclude($adaptation->method);
-                } else {
-                    throw new ParseErrorException(
-                        sprintf('Unexpected adaption type %s', get_class($adaptation)),
-                        ParseErrorException::UnexpectedExpr
-                    );
+
+                    continue;
                 }
+
+                throw new ParseErrorException(
+                    sprintf('Unexpected adaption type %s', get_class($adaptation)),
+                    ParseErrorException::UnexpectedExpr
+                );
             }
 
         }
 
         private function getTraitUse($traitName) {
-            if (!$this->unit->usesTtrait($traitName)) {
+            if (!$this->unit->usesTrait($traitName)) {
                 throw new ParseErrorException(
                     sprintf('Referenced trait "%s" not used', $traitName),
                     ParseErrorException::GeneralParseError
@@ -227,6 +257,8 @@ namespace TheSeer\phpDox\Collector\Backend {
             $method->setFinal($node->isFinal());
             $method->setStatic($node->isStatic());
 
+            $this->processMethodReturnType($method, $node->getReturnType());
+
             $visibility = 'public';
             if ($node->isPrivate()) {
                 $visibility = 'private';
@@ -248,6 +280,47 @@ namespace TheSeer\phpDox\Collector\Backend {
             }
         }
 
+        private function processMethodReturnType(MethodObject $method, $returnType) {
+            if ($returnType === null) {
+                return;
+            }
+
+            if (in_array($returnType, ['void','float','int','string','bool','callable','array'])) {
+                $returnTypeObject = $method->setReturnType($returnType);
+                $returnTypeObject->setNullable(false);
+                return;
+            }
+
+            if ($returnType instanceof \PhpParser\Node\Name\FullyQualified) {
+                $returnTypeObject = $method->setReturnType($returnType->toString());
+                $returnTypeObject->setNullable(false);
+                return;
+            }
+
+            if ($returnType instanceof NullableType) {
+                if ((string)$returnType->type === 'self') {
+                    $returnTypeObject = $method->setReturnType($this->unit->getName());
+                } else {
+                    $returnTypeObject = $method->setReturnType($returnType->type);
+                }
+                $returnTypeObject->setNullable(true);
+                return;
+            }
+
+            if ($returnType instanceof \PhpParser\Node\Name) {
+                $returnTypeObject = $method->setReturnType(
+                    $this->unit->getName()
+                );
+                $returnTypeObject->setNullable(false);
+                return;
+            }
+
+            throw new ParseErrorException(
+                sprintf("Unexpected return type definition %s",
+                    get_class($returnType)
+                ),ParseErrorException::UnexpectedExpr);
+        }
+
         private function processInlineComments(MethodObject $method, array $stmts) {
             foreach($stmts as $stmt) {
                 if ($stmt->hasAttribute('comments')) {
@@ -281,11 +354,13 @@ namespace TheSeer\phpDox\Collector\Backend {
 
             $resolved = $this->resolveExpressionValue($constNode->value);
 
-            $const->setType($resolved['type']);
             $const->setValue($resolved['value']);
             if (isset($resolved['constant'])) {
                 $const->setConstantReference($resolved['constant']);
             }
+            if (isset($resolved['type'])) {
+                $const->setType($resolved['type']);
+            }
 
             $docComment = $node->getDocComment();
             if ($docComment !== NULL) {
@@ -317,68 +392,81 @@ namespace TheSeer\phpDox\Collector\Backend {
         }
 
         private function setVariableType(AbstractVariableObject $variable, $type = NULL) {
+            if ($type instanceof NullableType) {
+                $variable->setNullable(true);
+                $type = $type->type;
+            }
+
             if ($type === NULL) {
                 $variable->setType('{unknown}');
                 return;
             }
-            if ($type === 'array') {
-                $variable->setType('array');
+
+            if ($variable->isInternalType($type)) {
+                $variable->setType($type);
                 return;
             }
+
             if ($type instanceof \PhpParser\Node\Name\FullyQualified) {
                 $variable->setType( (string)$type);
                 return;
             }
+
             $type = (string)$type;
             if (isset($this->aliasMap[$type])) {
                 $type = $this->aliasMap[$type];
-            } elseif ($type[0]!='\\') {
+            } elseif ($type[0]!=='\\') {
                 $type = $this->namespace . '\\' . $type;
             }
             $variable->setType($type);
         }
 
-        private function resolveExpressionValue(\PhpParser\Node\Expr $expr) {
-            if ($expr instanceof \PhpParser\Node\Scalar\String_) {
+        private function resolveExpressionValue(Expr $expr) {
+            if ($expr instanceof String_) {
                 return array(
                     'type' => 'string',
                     'value' => $expr->getAttribute('originalValue')
                 );
             }
 
-            if ($expr instanceof \PhpParser\Node\Scalar\LNumber ||
-                $expr instanceof \PhpParser\Node\Expr\UnaryMinus ||
-                $expr instanceof \PhpParser\Node\Expr\UnaryPlus) {
+            if ($expr instanceof LNumber ||
+                $expr instanceof UnaryMinus ||
+                $expr instanceof UnaryPlus) {
                 return array(
                     'type' => 'integer',
                     'value' => $expr->getAttribute('originalValue')
                 );
             }
 
-            if ($expr instanceof \PhpParser\Node\Scalar\DNumber) {
+            if ($expr instanceof DNumber) {
                 return array(
                     'type' => 'float',
                     'value' => $expr->getAttribute('originalValue')
                 );
             }
 
-            if ($expr instanceof \PhpParser\Node\Expr\Array_) {
+            if ($expr instanceof Array_) {
                 return array(
                     'type' => 'array',
                     'value' => '' // @todo add array2xml?
                 );
             }
 
-            if ($expr instanceof \PhpParser\Node\Expr\ClassConstFetch) {
+            if ($expr instanceof ClassConstFetch) {
                 return array(
                     'type' => '{unknown}',
                     'value' => '',
-                    'constant' => join('\\', $expr->class->parts) . '::' . $expr->name
+                    'constant' => implode('\\', $expr->class->parts) . '::' . $expr->name
                 );
             }
 
-            if ($expr instanceof \PhpParser\Node\Expr\ConstFetch) {
-                $reference = join('\\', $expr->name->parts);
+            if ($expr instanceof ConstFetch) {
+                $reference = implode('\\', $expr->name->parts);
+                if (strtolower($reference) === 'null') {
+                    return array(
+                        'value' => 'NULL'
+                    );
+                }
                 if (in_array(strtolower($reference), array('true', 'false'))) {
                     return array(
                         'type' => 'boolean',
@@ -388,11 +476,11 @@ namespace TheSeer\phpDox\Collector\Backend {
                 return array(
                     'type' => '{unknown}',
                     'value' => '',
-                    'constant' => join('\\', $expr->name->parts)
+                    'constant' => implode('\\', $expr->name->parts)
                 );
             }
 
-            if ($expr instanceof \PhpParser\Node\Scalar\MagicConst\Line) {
+            if ($expr instanceof MagicConst\Line) {
                 return array(
                     'type' => 'integer',
                     'value' => '',
@@ -400,7 +488,7 @@ namespace TheSeer\phpDox\Collector\Backend {
                 );
             }
 
-            if ($expr instanceof \PhpParser\Node\Scalar\MagicConst) {
+            if ($expr instanceof MagicConst) {
                 return array(
                     'type' => 'string',
                     'value' => '',
@@ -408,6 +496,16 @@ namespace TheSeer\phpDox\Collector\Backend {
                 );
             }
 
+            if ($expr instanceof BinaryOp) {
+                $code = (new \PhpParser\PrettyPrinter\Standard)->prettyPrint([$expr]);
+
+                return array(
+                    'type' => 'expression',
+                    'value' => substr($code,0,-1)
+                );
+
+            }
+
             $type = get_class($expr);
             $line = $expr->getLine();
             $file = $this->result->getFileName();
@@ -416,21 +514,26 @@ namespace TheSeer\phpDox\Collector\Backend {
         }
 
         /**
-         * @param AbstractVariableObject     $variable
-         * @param \PhpParser\Node\Expr       $default
-         * @return string
+         * @param AbstractVariableObject $variable
+         * @param Expr                   $default
+         *
+         * @throws ParseErrorException
          */
-        private function setVariableDefaultValue(AbstractVariableObject $variable, \PhpParser\Node\Expr $default = NULL) {
+        private function setVariableDefaultValue(AbstractVariableObject $variable, Expr $default = NULL) {
             if ($default === NULL) {
                 return;
             }
+
             $resolved = $this->resolveExpressionValue($default);
-            $variable->setType($resolved['type']);
             $variable->setDefault($resolved['value']);
+
+            if (isset($resolved['type'])) {
+                $variable->setType($resolved['type']);
+            }
+
             if (isset($resolved['constant'])) {
                 $variable->setConstant($resolved['constant']);
             }
         }
-
     }
 }
