@@ -1,6 +1,6 @@
 <?php
 /**
- * Copyright (c) 2010-2015 Arne Blankerts <arne@blankerts.de>
+ * Copyright (c) 2010-2018 Arne Blankerts <arne@blankerts.de>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without modification,
@@ -287,7 +287,7 @@ namespace TheSeer\phpDox\Collector {
          *
          * @return bool
          */
-        public function usesTtrait($name) {
+        public function usesTrait($name) {
             return $this->rootNode->query(sprintf('phpdox:uses[@full="%s"]', $name))->length > 0;
         }
 
@@ -336,6 +336,15 @@ namespace TheSeer\phpDox\Collector {
             return new TraitUseObject($node);
         }
 
+        public function getAmbiguousTraitUse() {
+            $node = $this->rootNode->queryOne('phpdox:ambiguous[@type="trait-alias"]');
+            if (!$node) {
+                $node = $this->rootNode->appendElementNS(self::XMLNS, 'ambiguous');
+                $node->setAttribute('type','trait-alias');
+            }
+            return new TraitUseObject($node);
+        }
+
         /**
          * @param string $dependency
          */
@@ -514,6 +523,13 @@ namespace TheSeer\phpDox\Collector {
                 }
             }
 
+            if ($trait->usesTraits()) {
+                foreach($trait->getUsedTraits() as $name) {
+                    $used = $container->appendElementNS( self::XMLNS, 'uses');
+                    $this->setName($name, $used);
+                }
+            }
+
             foreach($trait->getConstants() as $constant) {
                 $container->appendChild( $this->dom->importNode($constant->export(), TRUE) );
             }
@@ -524,6 +540,7 @@ namespace TheSeer\phpDox\Collector {
                 $container->appendChild($memberNode);
             }
 
+            $ambiguousContainer = $this->dom->queryOne('//phpdox:ambiguous[@type="trait-alias"]');
             foreach($trait->getExportedMethods() as $method) {
                 $methodName = $method->getName();
                 $methodNode = $this->dom->importNode($method->export(), TRUE);
@@ -534,6 +551,22 @@ namespace TheSeer\phpDox\Collector {
 
                 $this->adjustStaticResolution($methodNode);
 
+                if ($ambiguousContainer !== NULL) {
+                    $ambiguousMethod = $ambiguousContainer->queryOne(
+                        sprintf('phpdox:alias[@method="%s"]', $methodName)
+                    );
+                    if ($ambiguousMethod !== null) {
+                        $usesNode = $this->dom->queryOne(
+                            sprintf('//phpdox:uses[@full="%s"]', $trait->getName())
+                        );
+                        $usesNode->appendChild($ambiguousMethod);
+                        if ($ambiguousContainer->query('phpdox:alias')->length === 0) {
+                            $ambiguousContainer->parentNode->removeChild($ambiguousContainer);
+                            $ambiguousContainer = NULL;
+                        }
+                    }
+                }
+
                 $aliasNode = NULL;
                 if ($use->isAliased($methodName)) {
                     $aliasNode = $methodNode->cloneNode(true);
