@@ -1,6 +1,6 @@
 <?php
 /**
- * Copyright (c) 2010-2015 Arne Blankerts <arne@blankerts.de>
+ * Copyright (c) 2010-2018 Arne Blankerts <arne@blankerts.de>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without modification,
@@ -50,6 +50,10 @@ namespace TheSeer\phpDox {
             $this->ctx = $ctx;
         }
 
+        public function isPublicOnlyMode() {
+            return $this->config->isPublicOnlyMode();
+        }
+
         /**
          * @return array
          */
