@@ -20,12 +20,15 @@ namespace TheSeer\phpDox\Generator\Enricher {
          */
         private $coveragePath;
 
+        /**
+         * @var FileInfo
+         */
+        private $sourceDirectory;
         /**
          * @var fDOMDocument
          */
         private $index;
 
-
         private $results = array();
         private $coverage = array();
 
@@ -36,6 +39,8 @@ namespace TheSeer\phpDox\Generator\Enricher {
          */
         public function __construct(PHPUnitConfig $config) {
             $this->coveragePath = $config->getCoveragePath();
+            $this->sourceDirectory = $config->getSourceDirectory();
+
             $this->index = $this->loadXML('index.xml');
         }
 
@@ -56,6 +61,7 @@ namespace TheSeer\phpDox\Generator\Enricher {
                     if (!$classNode) {
                         continue;
                     }
+                    /** @var fDOMElement $classNode */
                     $container = $this->getEnrichtmentContainer($classNode, 'phpunit');
                     $resultNode = $container->appendElementNS(self::XMLNS, 'result');
                     foreach($results as $key => $value) {
@@ -112,13 +118,20 @@ namespace TheSeer\phpDox\Generator\Enricher {
                 $fname = (string)$this->coveragePath . '/' . $fname;
                 if (!file_exists($fname)) {
                     throw new EnricherException(
-                        sprintf('PHPUnit xml file "%s" not found.', $fname),
+                        sprintf('PHPUnit coverage xml file "%s" not found.', $fname),
                         EnricherException::LoadError
                     );
                 }
                 $dom = new fDOMDocument();
                 $dom->load($fname);
-                $dom->registerNamespace('pu', 'http://schema.phpunit.de/coverage/1.0');
+
+                if ($dom->documentElement->namespaceURI != self::XMLNS) {
+                    throw new EnricherException(
+                        'Wrong namspace - not a PHPUnit code coverage file',
+                        EnricherException::LoadError
+                    );
+                }
+                $dom->registerNamespace('pu', self::XMLNS);
                 return $dom;
             } catch (fDOMException $e) {
                 throw new EnricherException(
@@ -154,7 +167,8 @@ namespace TheSeer\phpDox\Generator\Enricher {
                 'INCOMPLETE'  => 0,
                 'FAILURE'  => 0,
                 'ERROR'  => 0,
-                'RISKY'  => 0
+                'RISKY'  => 0,
+                'WARNING' => 0
             );
 
             $methods = $unit->query('/phpdox:*/phpdox:constructor|/phpdox:*/phpdox:destructor|/phpdox:*/phpdox:method');
@@ -215,15 +229,6 @@ namespace TheSeer\phpDox\Generator\Enricher {
             $this->coverage[$classNamespace][$className] = $coverageTarget->cloneNode(false);
         }
 
-        /**
-         * @return FileInfo
-         */
-        private function getSourceDirectory() {
-            $baseDir = $this->index->queryOne('//pu:project/pu:directory');
-            $srcDir = new FileInfo($baseDir->getAttribute('name'));
-            return $srcDir;
-        }
-
         /**
          * @param fDOMDocument $dom
          *
@@ -239,13 +244,11 @@ namespace TheSeer\phpDox\Generator\Enricher {
             }
 
             $fileInfo = new FileInfo($fileNode->getAttribute('path'));
-            $srcDir = $this->getSourceDirectory();
-
-            $paths = explode('/', (string)$fileInfo->getRelative($srcDir));
+            $paths = explode('/', (string)$fileInfo->getRelative($this->sourceDirectory));
             $file = $fileNode->getAttribute('file');
             $paths = array_slice($paths, 1);
 
-            $query = sprintf('//pu:project/pu:directory[@name = "%s"]', $srcDir->getRealPath());
+            $query = sprintf('//pu:project/pu:directory');
             foreach ($paths as $path) {
                 $query .= sprintf('/pu:directory[@name = "%s"]', $path);
             }
@@ -256,8 +259,7 @@ namespace TheSeer\phpDox\Generator\Enricher {
                 throw new PHPUnitEnricherException('No coverage information for file');
             }
 
-            $refDom = $this->loadXML($phpunitFileNode->getAttribute('href'));
-            return $refDom;
+            return $this->loadXML($phpunitFileNode->getAttribute('href'));
         }
     }
 
