@@ -35,6 +35,10 @@ namespace TheSeer\phpDox\Generator\Enricher {
             if ($path != '') { $path .= '/'; }
             $coverage = $this->context->queryOne('cfg:coverage');
             if ($coverage && $coverage->hasAttribute('path')) {
+                $cfgPath = $coverage->getAttribute('path');
+                if ($cfgPath[0] === '/') {
+                    $path = '';
+                }
                 $path .= $coverage->getAttribute('path');
             } else {
                 $path .= 'coverage';
@@ -42,6 +46,13 @@ namespace TheSeer\phpDox\Generator\Enricher {
             return new FileInfo($path);
         }
 
+        /**
+         * @return FileInfo
+         */
+        public function getSourceDirectory() {
+            return $this->generator->getProjectConfig()->getSourceDirectory();
+        }
+
     }
 
 }
