@@ -1,6 +1,6 @@
 <?php
 /**
- * Copyright (c) 2010-2015 Arne Blankerts <arne@blankerts.de>
+ * Copyright (c) 2010-2018 Arne Blankerts <arne@blankerts.de>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without modification,
@@ -37,6 +37,4 @@
  */
 
 require __DIR__ . '/../src/autoload.php';
-$vendor = __DIR__ . '/../vendor';
-require __DIR__ . '/../src/vendor.php';
-
+require __DIR__ . '/../vendor/autoload.php';
